<?php
/**
 * Enqueue functions.
 *
 * @package cheshalo
 */

use Automattic\WooCommerce\Blocks\Utils\CartCheckoutUtils;
use Elementor\Plugin;
use XTS\Modules\Checkout_Order_Table;
use XTS\Modules\Layouts\Main;
use XTS\Modules\Parts_Css_Files;

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_is_combined_needed' ) ) {
	/**
	 * Is combined needed.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key Combined key.
	 * @param mixed  $default Default value.
	 *
	 * @return bool
	 */
	function cheshalo_is_combined_needed( $key, $default = false ) {
		return apply_filters( 'cheshalo_enqueue_' . $key, $default ) || ( cheshalo_is_elementor_installed() && ( cheshalo_elementor_is_edit_mode() || cheshalo_elementor_is_preview_mode() ) ) || is_singular( 'cheshalo_layout' );
	}
}

if ( ! function_exists( 'cheshalo_is_minified_needed' ) ) {
	/**
	 * Is minified JS files needed.
	 *
	 * @since 1.0.0
	 *
	 * @return bool
	 */
	function cheshalo_is_minified_needed() {
		return apply_filters( 'cheshalo_enqueue_minified_js_files', ! defined( 'SCRIPT_DEBUG' ) || ! SCRIPT_DEBUG );
	}
}

if ( ! function_exists( 'cheshalo_register_libraries_scripts' ) ) {
	/**
	 * Register libraries scripts.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_register_libraries_scripts() {
		$config   = cheshalo_get_config( 'js-libraries' );
		$minified = cheshalo_is_minified_needed() ? '.min' : '';
		$version  = cheshalo_get_theme_info( 'Version' );

		if ( cheshalo_is_combined_needed( 'combined_js_libraries' ) ) {
			return;
		}

		foreach ( $config as $key => $libraries ) {
			foreach ( $libraries as $library ) {
				$src = CHESHALO_THEME_DIR . $library['file'] . $minified . '.js';

				wp_register_script( 'wd-' . $key . '-library', $src, $library['dependency'], $version, $library['in_footer'] );
			}
		}
	}

	add_action( 'wp_enqueue_scripts', 'cheshalo_register_libraries_scripts', 10 );
}

if ( ! function_exists( 'cheshalo_register_scripts' ) ) {
	/**
	 * Register scripts.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_register_scripts() {
		$config   = cheshalo_get_config( 'js-scripts' );
		$minified = cheshalo_is_minified_needed() ? '.min' : '';
		$version  = cheshalo_get_theme_info( 'Version' );

		if ( cheshalo_is_combined_needed( 'combined_js' ) ) {
			return;
		}

		foreach ( $config as $scripts ) {
			foreach ( $scripts as $script ) {
				$src = CHESHALO_THEME_DIR . $script['file'] . $minified . '.js';
				$deps = array();

				if ( 'cheshalo-theme' !== $script['name'] ) {
					if ( 'scrollbar' !== $script['name'] ) {
						$deps = array( 'cheshalo-theme' );
					}

					$name = 'wd-' . $script['name'];
				} else {
					$name = $script['name'];
				}

				wp_register_script( $name, $src, $deps, $version, $script['in_footer'] );
			}
		}
	}

	add_action( 'wp_enqueue_scripts', 'cheshalo_register_scripts', 20 );
}

if ( ! function_exists( 'cheshalo_enqueue_base_scripts' ) ) {
	/**
	 * Enqueue base scripts.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_enqueue_base_scripts() {
		$minified = cheshalo_is_minified_needed() ? '.min' : '';
		$version  = cheshalo_get_theme_info( 'Version' );

		// General.
		wp_enqueue_script( 'wpb_composer_front_js', false, array(), $version ); // phpcs:ignore
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}
		if ( cheshalo_is_elementor_installed() && apply_filters( 'cheshalo_enqueue_elementor_scripts', true ) ) {
			Elementor\Plugin::$instance->frontend->enqueue_scripts();
		}

		// Libraries.
		if ( cheshalo_is_combined_needed( 'combined_js_libraries' ) ) {
			wp_enqueue_script( 'wd-libraries', CHESHALO_THEME_DIR . '/js/libs/combine' . $minified . '.js', array( 'jquery' ), $version, true );
		} else {
			cheshalo_enqueue_js_library( 'device' );

			if ( cheshalo_get_opt( 'ajax_shop' ) && cheshalo_is_shop_archive() && ( function_exists( 'cheshalo_elementor_has_location' ) && ! cheshalo_elementor_has_location( 'archive' ) || ! function_exists( 'cheshalo_elementor_has_location' ) ) ) {
				cheshalo_enqueue_js_library( 'pjax' );
			}

			if ( ( cheshalo_get_opt( 'ajax_portfolio' ) && cheshalo_is_portfolio_archive() ) ) {
				cheshalo_enqueue_js_library( 'pjax' );
			}

			if ( ! cheshalo_woocommerce_installed() ) {
				cheshalo_enqueue_js_library( 'cookie' );
			}

			$config = cheshalo_get_config( 'js-libraries' );
			foreach ( $config as $key => $libraries ) {
				foreach ( $libraries as $library ) {
					if ( 'always' === cheshalo_get_opt( $library['name'] . '_library' ) ) {
						cheshalo_enqueue_js_library( $key );
					}
				}
			}
		}

		if ( 'always' === cheshalo_get_opt( 'swiper_library' ) && ! cheshalo_get_opt( 'elementor_frontend' ) ) {
			wp_enqueue_script( 'swiper' );
		}

		if ( 'always' === cheshalo_get_opt( 'el_waypoints_library' ) && ! cheshalo_get_opt( 'elementor_frontend' ) ) {
			wp_enqueue_script( 'elementor-waypoints' );
		}

		// Scripts.
		if ( cheshalo_is_combined_needed( 'combined_js' ) ) {
			wp_enqueue_script( 'imagesloaded' );
			wp_enqueue_script( 'cheshalo-theme', CHESHALO_THEME_DIR . '/js/scripts/combine' . $minified . '.js', array(), $version, true );
		} else {
			cheshalo_enqueue_js_script( 'cheshalo-theme' );
			cheshalo_enqueue_js_script( 'woocommerce-notices' );
			cheshalo_enqueue_js_script( 'scrollbar' );

			if ( is_admin_bar_showing() ) {
				cheshalo_enqueue_js_script( 'admin-bar-slider-menu' );
			}

			if ( cheshalo_woocommerce_installed() ) {
				if ( is_cart() || is_checkout() || is_account_page() ) {
					cheshalo_enqueue_js_script( 'woocommerce-wrapp-table' );
				}

				if ( is_cart() || is_checkout() ) {
					wp_enqueue_script( 'wc-cart-fragments' );
				}

				if ( cheshalo_get_opt( 'update_cart_quantity_change' ) && is_cart() && ! WC()->cart->is_empty() ) {
					cheshalo_enqueue_js_script( 'cart-quantity' );
				}

				if ( is_singular( 'product' ) && apply_filters( 'cheshalo_wc_track_recently_product_viewed', true ) ) {
					cheshalo_enqueue_js_script( 'track-product-recently-viewed' );
				}
			}

			if ( cheshalo_get_opt( 'widget_toggle' ) ) {
				cheshalo_enqueue_js_script( 'widgets-hidable' );
			}

			if ( ( cheshalo_get_opt( 'ajax_shop' ) && cheshalo_is_shop_archive() ) ) {
				cheshalo_enqueue_js_script( 'ajax-filters' );
				cheshalo_enqueue_js_script( 'shop-page-init' );
				cheshalo_enqueue_js_script( 'back-history' );
			}

			if ( 'disable' !== cheshalo_get_opt( 'shop_widgets_collapse', 'disable' ) && cheshalo_is_shop_archive() ) {
				cheshalo_enqueue_js_script( 'widget-collapse' );
			}

			if ( ( cheshalo_get_opt( 'ajax_portfolio' ) && cheshalo_is_portfolio_archive() ) ) {
				cheshalo_enqueue_js_script( 'ajax-portfolio' );
			}

			$scripts_always = cheshalo_get_opt( 'scripts_always_use' );
			if ( is_array( $scripts_always ) ) {
				foreach ( $scripts_always as $script ) {
					cheshalo_enqueue_js_script( $script );
				}
			}
		}

		if ( cheshalo_is_elementor_installed() && ( cheshalo_elementor_is_edit_mode() || cheshalo_elementor_is_preview_mode() ) ) {
			wp_enqueue_script( 'wd-google-map-api', 'https://maps.google.com/maps/api/js?libraries=geometry&callback=cheshaloThemeModule.googleMapsCallback&v=weekly&key=' . cheshalo_get_opt( 'google_map_api_key' ), array( 'cheshalo-theme' ), $version, true );
			wp_enqueue_script( 'wd-maplace', CHESHALO_THEME_DIR . '/js/libs/maplace' . $minified . '.js', array( 'wd-google-map-api' ), $version, true );
		}

		wp_add_inline_script( 'cheshalo-theme', cheshalo_settings_js() );
		wp_localize_script( 'cheshalo-theme', 'cheshalo_settings', cheshalo_get_localized_string_array() );

		wp_register_style( 'cheshalo-inline-css', '' );
	}

	add_action( 'wp_enqueue_scripts', 'cheshalo_enqueue_base_scripts', 30 );
}

if ( ! function_exists( 'cheshalo_enqueue_js_script' ) ) {
	/**
	 * Enqueue js script.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key        Script name.
	 * @param string $responsive Responsive key.
	 */
	function cheshalo_enqueue_js_script( $key, $responsive = '' ) {
		$config          = cheshalo_get_config( 'js-scripts' );
		$scripts_not_use = cheshalo_get_opt( 'scripts_not_use' );

		if ( ! isset( $config[ $key ] ) || cheshalo_is_combined_needed( 'combined_js' ) ) {
			return;
		}

		foreach ( $config[ $key ] as $data ) {
			if ( ( 'only_mobile' === $responsive && ! wp_is_mobile() ) || ( 'only_desktop' === $responsive && wp_is_mobile() ) || ( is_array( $scripts_not_use ) && in_array( $data['name'], $scripts_not_use ) ) ) { // phpcs:ignore
				continue;
			}

			$name = 'cheshalo-theme' !== $data['name'] ? 'wd-' . $data['name'] : $data['name'];
			wp_enqueue_script( $name );
		}
	}
}

if ( ! function_exists( 'cheshalo_enqueue_js_library' ) ) {
	/**
	 * Enqueue js library.
	 *
	 * @since 1.0.0
	 *
	 * @param string $key        Script name.
	 * @param string $responsive Responsive key.
	 */
	function cheshalo_enqueue_js_library( $key, $responsive = '' ) {
		$config = cheshalo_get_config( 'js-libraries' );

		if ( ! isset( $config[ $key ] ) || cheshalo_is_combined_needed( 'combined_js_libraries' ) ) {
			return;
		}

		foreach ( $config[ $key ] as $data ) {
			if ( ( 'only_mobile' === $responsive && ! wp_is_mobile() ) || ( 'only_desktop' === $responsive && wp_is_mobile() ) || 'not_use' === cheshalo_get_opt( $data['name'] . '_library' ) ) {
				continue;
			}

			wp_enqueue_script( 'wd-' . $key . '-library' );
		}
	}
}

if ( ! function_exists( 'cheshalo_dequeue_scripts' ) ) {
	/**
	 * Dequeue scripts.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_dequeue_scripts() {
		$dequeue_scripts = explode( ',', cheshalo_get_opt( 'dequeue_scripts' ) );

		if ( is_array( $dequeue_scripts ) ) {
			foreach ( $dequeue_scripts as $script ) {
				wp_deregister_script( trim( $script ) );
				wp_dequeue_script( trim( $script ) );
			}
		}

		wp_dequeue_script( 'flexslider' );
		wp_dequeue_script( 'photoswipe-ui-default' );
		wp_dequeue_script( 'prettyPhoto-init' );
		wp_dequeue_script( 'prettyPhoto' );
		wp_dequeue_style( 'photoswipe-default-skin' );

		// Remove CF7.
		if ( ! cheshalo_get_opt( 'cf7_js', '1' ) ) {
			wp_deregister_script( 'contact-form-7' );
			wp_dequeue_script( 'contact-form-7' );
		}

		// Remove animations.
		if ( ! cheshalo_get_opt( 'elementor_animations', '1' ) ) {
			wp_deregister_style( 'elementor-animations' );
			wp_dequeue_style( 'elementor-animations' );
		}

		// Remove icons.
		if ( ! cheshalo_get_opt( 'elementor_icons', '1' ) && ( ! is_user_logged_in() || ( is_user_logged_in() && ! current_user_can( 'administrator' ) ) ) ) {
			wp_deregister_style( 'elementor-icons' );
			wp_dequeue_style( 'elementor-icons' );
		}

		// Remove dialog.
		if ( ! cheshalo_get_opt( 'elementor_dialog_library' ) && cheshalo_is_elementor_installed() ) {
			$scripts = wp_scripts();
			if ( ! ( $scripts instanceof WP_Scripts ) ) {
				return;
			}

			$handles_to_remove = array(
				'elementor-dialog',
			);

			$handles_updated = false;

			foreach ( $scripts->registered as $dependency_object_id => $dependency_object ) {
				if ( 'elementor-frontend' === $dependency_object_id ) {
					if ( ! ( $dependency_object instanceof _WP_Dependency ) || empty( $dependency_object->deps ) ) {
						return;
					}

					foreach ( $dependency_object->deps as $dep_key => $handle ) {
						if ( in_array( $handle, $handles_to_remove ) ) { // phpcs:ignore
							unset( $dependency_object->deps[ $dep_key ] );
							$dependency_object->deps = array_values( $dependency_object->deps );
							$handles_updated         = true;
						}
					}
				}
			}

			if ( $handles_updated && ! cheshalo_elementor_is_edit_mode() && ! cheshalo_elementor_is_preview_mode() ) {
				wp_deregister_script( 'elementor-dialog' );
				wp_dequeue_script( 'elementor-dialog' );
			}
		}

		// Elementor frontend.
		if ( ! cheshalo_get_opt( 'elementor_frontend', '1' ) && cheshalo_is_elementor_installed() && ! cheshalo_elementor_is_edit_mode() && ! cheshalo_elementor_is_preview_mode() ) {
			wp_deregister_script( 'elementor-frontend' );
			wp_dequeue_script( 'elementor-frontend' );
		}

		// Zoom.
		if ( 'zoom' !== cheshalo_get_opt( 'image_action' ) ) {
			wp_deregister_script( 'zoom' );
			wp_dequeue_script( 'zoom' );
		}

		// Gutenberg.
		if ( cheshalo_get_opt( 'disable_gutenberg_css' ) ) {
			wp_deregister_style( 'wp-block-library' );
			wp_dequeue_style( 'wp-block-library' );

			wp_deregister_style( 'wc-block-style' );
			wp_dequeue_style( 'wc-block-style' );

			wp_deregister_style( 'wc-blocks-style' );
			wp_dequeue_style( 'wc-blocks-style' );

			wp_deregister_style( 'wc-blocks-packages-style' );
			wp_dequeue_style( 'wc-blocks-packages-style' );

			wp_dequeue_style( 'classic-theme-styles' );

			if ( cheshalo_woocommerce_installed() && ! empty( wp_styles()->registered ) ) {
				foreach ( wp_styles()->registered as $key => $data ) {
					if ( false !== strpos( $key, 'wc-blocks-style-' ) ) {
						wp_deregister_style( $key );
						wp_dequeue_script( $key );
					}
				}
			}
		}
	}

	add_action( 'wp_enqueue_scripts', 'cheshalo_dequeue_scripts', 2000 );
}

if ( ! function_exists( 'cheshalo_clear_menu_transient' ) ) {
	/**
	 * Clear menu session storage key hash on save menu/html block.
	 *
	 * @since 1.0.0
	 */
	function cheshalo_clear_menu_transient() {
		delete_transient( 'cheshalo-menu-hash-time' );
	}

	add_action( 'wp_update_nav_menu_item', 'cheshalo_clear_menu_transient', 11, 1 );
	add_action( 'save_post_cms_block', 'cheshalo_clear_menu_transient', 30, 3 );
}

if ( ! function_exists( 'cheshalo_get_localized_string_array' ) ) {
	/**
	 * Get localize array
	 *
	 * @since 1.0.0
	 *
	 * @return array
	 */
	function cheshalo_get_localized_string_array() {
		$version             = cheshalo_get_theme_info( 'Version' );
		$menu_hash_transient = get_transient( 'cheshalo-menu-hash-time' );
		if ( false === $menu_hash_transient ) {
			$menu_hash_transient = time();
			set_transient( 'cheshalo-menu-hash-time', $menu_hash_transient );
		}

		$site_custom_width     = cheshalo_get_opt( 'site_custom_width' );
		$predefined_site_width = cheshalo_get_opt( 'site_width' );

		$site_width = '';

		if ( 'full-width' === $predefined_site_width ) {
			$site_width = 1222;
		} elseif ( 'boxed' === $predefined_site_width ) {
			$site_width = 1160;
		} elseif ( 'boxed-2' === $predefined_site_width ) {
			$site_width = 1160;
		} elseif ( 'wide' === $predefined_site_width ) {
			$site_width = 1600;
		} elseif ( 'custom' === $predefined_site_width ) {
			$site_width = $site_custom_width;
		}

		return apply_filters(
			'cheshalo_localized_string_array',
			array(
				'menu_storage_key'                       => apply_filters( 'cheshalo_menu_storage_key', 'cheshalo_' . md5( get_current_blog_id() . '_' . get_site_url( get_current_blog_id(), '/' ) . get_template() . $menu_hash_transient . $version ) ),
				'ajax_dropdowns_save'                    => apply_filters( 'xts_ajax_dropdowns_save', true ),
				'photoswipe_close_on_scroll'             => apply_filters( 'cheshalo_photoswipe_close_on_scroll', true ),
				'woocommerce_ajax_add_to_cart'           => get_option( 'woocommerce_enable_ajax_add_to_cart' ),
				'variation_gallery_storage_method'       => cheshalo_get_opt( 'variation_gallery_storage_method', 'old' ),
				'elementor_no_gap'                       => cheshalo_get_opt( 'negative_gap', 'enabled' ),
				'adding_to_cart'                         => esc_html__( 'Processing', 'cheshalo' ),
				'added_to_cart'                          => esc_html__( 'Product was successfully added to your cart.', 'cheshalo' ),
				'continue_shopping'                      => esc_html__( 'Continue shopping', 'cheshalo' ),
				'view_cart'                              => esc_html__( 'View Cart', 'cheshalo' ),
				'go_to_checkout'                         => esc_html__( 'Checkout', 'cheshalo' ),
				'loading'                                => esc_html__( 'Loading...', 'cheshalo' ),
				'countdown_days'                         => esc_html__( 'days', 'cheshalo' ),
				'countdown_hours'                        => esc_html__( 'hr', 'cheshalo' ),
				'countdown_mins'                         => esc_html__( 'min', 'cheshalo' ),
				'countdown_sec'                          => esc_html__( 'sc', 'cheshalo' ),
				'cart_url'                               => ( cheshalo_woocommerce_installed() ) ? esc_url( wc_get_cart_url() ) : '',
				'ajaxurl'                                => admin_url( 'admin-ajax.php' ),
				'add_to_cart_action'                     => ( cheshalo_get_opt( 'add_to_cart_action' ) ) ? esc_js( cheshalo_get_opt( 'add_to_cart_action' ) ) : 'widget',
				'added_popup'                            => ( cheshalo_get_opt( 'added_to_cart_popup' ) ) ? 'yes' : 'no',
				'categories_toggle'                      => ( cheshalo_get_opt( 'categories_toggle' ) ) ? 'yes' : 'no',
				'enable_popup'                           => ( cheshalo_get_opt( 'promo_popup' ) ) ? 'yes' : 'no',
				'popup_delay'                            => ( cheshalo_get_opt( 'promo_timeout' ) ) ? (int) cheshalo_get_opt( 'promo_timeout' ) : 1000,
				'popup_event'                            => cheshalo_get_opt( 'popup_event' ),
				'popup_scroll'                           => ( cheshalo_get_opt( 'popup_scroll' ) ) ? (int) cheshalo_get_opt( 'popup_scroll' ) : 1000,
				'popup_pages'                            => ( cheshalo_get_opt( 'popup_pages' ) ) ? (int) cheshalo_get_opt( 'popup_pages' ) : 0,
				'promo_popup_hide_mobile'                => ( cheshalo_get_opt( 'promo_popup_hide_mobile' ) ) ? 'yes' : 'no',
				'product_images_captions'                => ( cheshalo_get_opt( 'product_images_captions' ) ) ? 'yes' : 'no',
				'ajax_add_to_cart'                       => ( apply_filters( 'cheshalo_ajax_add_to_cart', true ) ) ? cheshalo_get_opt( 'single_ajax_add_to_cart' ) : false,
				'all_results'                            => esc_html__( 'View all results', 'cheshalo' ),
				'zoom_enable'                            => ( cheshalo_get_opt( 'image_action' ) === 'zoom' ) ? 'yes' : 'no',
				'ajax_scroll'                            => ( cheshalo_get_opt( 'ajax_scroll' ) ) ? 'yes' : 'no',
				'ajax_scroll_class'                      => apply_filters( 'cheshalo_ajax_scroll_class', '.main-page-wrapper' ),
				'ajax_scroll_offset'                     => apply_filters( 'cheshalo_ajax_scroll_offset', 100 ),
				'infinit_scroll_offset'                  => apply_filters( 'cheshalo_infinit_scroll_offset', 300 ),
				'product_slider_auto_height'             => ( cheshalo_get_opt( 'product_slider_auto_height' ) ) ? 'yes' : 'no',
				'price_filter_action'                    => ( apply_filters( 'price_filter_action', 'click' ) === 'submit' ) ? 'submit' : 'click',
				'product_slider_autoplay'                => apply_filters( 'cheshalo_product_slider_autoplay', false ),
				'close'                                  => esc_html__( 'Close (Esc)', 'cheshalo' ),
				'share_fb'                               => esc_html__( 'Share on Facebook', 'cheshalo' ),
				'pin_it'                                 => esc_html__( 'Pin it', 'cheshalo' ),
				'tweet'                                  => esc_html__( 'Share on X', 'cheshalo' ),
				'download_image'                         => esc_html__( 'Download image', 'cheshalo' ),
				'off_canvas_column_close_btn_text'       => esc_html__( 'Close', 'cheshalo' ),
				'cookies_version'                        => ( cheshalo_get_opt( 'cookies_version' ) ) ? (int) cheshalo_get_opt( 'cookies_version' ) : 1,
				'header_banner_version'                  => ( cheshalo_get_opt( 'header_banner_version' ) ) ? (int) cheshalo_get_opt( 'header_banner_version' ) : 1,
				'promo_version'                          => ( cheshalo_get_opt( 'promo_version' ) ) ? (int) cheshalo_get_opt( 'promo_version' ) : 1,
				'header_banner_close_btn'                => cheshalo_get_opt( 'header_close_btn' ) ? 'yes' : 'no',
				'header_banner_enabled'                  => cheshalo_get_opt( 'header_banner' ) ? 'yes' : 'no',
				'whb_header_clone'                       => cheshalo_get_config( 'header-clone-structure' ),
				'pjax_timeout'                           => apply_filters( 'cheshalo_pjax_timeout', 5000 ),
				'split_nav_fix'                          => apply_filters( 'cheshalo_split_nav_fix', false ),
				'shop_filters_close'                     => cheshalo_get_opt( 'shop_filters_close' ) ? 'yes' : 'no',
				'woo_installed'                          => cheshalo_woocommerce_installed(),
				'base_hover_mobile_click'                => cheshalo_get_opt( 'base_hover_mobile_click' ) ? 'yes' : 'no',
				'centered_gallery_start'                 => apply_filters( 'cheshalo_centered_gallery_start', 1 ),
				'quickview_in_popup_fix'                 => apply_filters( 'cheshalo_quickview_in_popup_fix', false ),
				'one_page_menu_offset'                   => apply_filters( 'cheshalo_one_page_menu_offset', 150 ),
				'hover_width_small'                      => apply_filters( 'cheshalo_hover_width_small', true ),
				'is_multisite'                           => is_multisite(),
				'current_blog_id'                        => get_current_blog_id(),
				'swatches_scroll_top_desktop'            => cheshalo_get_opt( 'swatches_scroll_top_desktop' ) ? 'yes' : 'no',
				'swatches_scroll_top_mobile'             => cheshalo_get_opt( 'swatches_scroll_top_mobile' ) ? 'yes' : 'no',
				'lazy_loading_offset'                    => cheshalo_get_opt( 'lazy_loading_offset' ),
				'add_to_cart_action_timeout'             => cheshalo_get_opt( 'add_to_cart_action_timeout' ) ? 'yes' : 'no',
				'add_to_cart_action_timeout_number'      => cheshalo_get_opt( 'add_to_cart_action_timeout_number' ),
				'single_product_variations_price'        => cheshalo_get_opt( 'single_product_variations_price' ) ? 'yes' : 'no',
				'google_map_style_text'                  => esc_html__( 'Custom style', 'cheshalo' ),
				'quick_shop'                             => cheshalo_get_opt( 'quick_shop_variable' ) ? 'yes' : 'no',
				'sticky_product_details_offset'          => apply_filters( 'cheshalo_sticky_product_details_offset', 150 ),
				'preloader_delay'                        => apply_filters( 'cheshalo_preloader_delay', 300 ),
				'comment_images_upload_size_text'        => sprintf( esc_html__( 'Some files are too large. Allowed file size is %s.', 'cheshalo' ), size_format( (int) cheshalo_get_opt( 'single_product_comment_images_upload_size' ) * MB_IN_BYTES ) ), // phpcs:ignore
				'comment_images_count_text'              => sprintf( esc_html__( 'You can upload up to %s images to your review.', 'cheshalo' ), cheshalo_get_opt( 'single_product_comment_images_count' ) ), // phpcs:ignore
				'single_product_comment_images_required' => cheshalo_get_opt( 'single_product_comment_images_required' ) ? 'yes' : 'no', // phpcs:ignore
				'comment_required_images_error_text'     => esc_html__( 'Image is required.', 'cheshalo' ), // phpcs:ignore
				'comment_images_upload_mimes_text'       => sprintf( esc_html__( 'You are allowed to upload images only in %s formats.', 'cheshalo' ), apply_filters( 'xts_comment_images_upload_mimes', 'png, jpeg' ) ), // phpcs:ignore
				'comment_images_added_count_text'        => esc_html__( 'Added %s image(s)', 'cheshalo' ), // phpcs:ignore
				'comment_images_upload_size'             => (int) cheshalo_get_opt( 'single_product_comment_images_upload_size' ) * MB_IN_BYTES,
				'comment_images_count'                   => cheshalo_get_opt( 'single_product_comment_images_count' ),
				'search_input_padding'                   => apply_filters( 'wd_search_input_padding', false ) ? 'yes' : 'no',
				'comment_images_upload_mimes'            => apply_filters(
					'cheshalo_comment_images_upload_mimes',
					array(
						'jpg|jpeg|jpe' => 'image/jpeg',
						'png'          => 'image/png',
					)
				),
				'home_url'                               => home_url( '/' ),
				'shop_url'                               => cheshalo_woocommerce_installed() ? esc_url( wc_get_page_permalink( 'shop' ) ) : '',
				'age_verify'                             => ( cheshalo_get_opt( 'age_verify' ) ) ? 'yes' : 'no',
				'banner_version_cookie_expires'          => apply_filters( 'cheshalo_banner_version_cookie_expires', 60 ),
				'promo_version_cookie_expires'           => apply_filters( 'cheshalo_promo_version_cookie_expires', 7 ),
				'age_verify_expires'                     => apply_filters( 'cheshalo_age_verify_expires', 30 ),
				'cart_redirect_after_add'                => get_option( 'woocommerce_cart_redirect_after_add' ),
				'swatches_labels_name'                   => cheshalo_get_opt( 'swatches_labels_name' ) ? 'yes' : 'no',
				'product_categories_placeholder'         => esc_html__( 'Select a category', 'woocommerce' ),
				'product_categories_no_results'          => esc_html__( 'No matches found', 'woocommerce' ),
				'cart_hash_key'                          => apply_filters( 'woocommerce_cart_hash_key', 'wc_cart_hash_' . md5( get_current_blog_id() . '_' . get_site_url( get_current_blog_id(), '/' ) . get_template() ) ),
				'fragment_name'                          => apply_filters( 'woocommerce_cart_fragment_name', 'wc_fragments_' . md5( get_current_blog_id() . '_' . get_site_url( get_current_blog_id(), '/' ) . get_template() ) ),
				'photoswipe_template'                    => '<div class="pswp" aria-hidden="true" role="dialog" tabindex="-1"><div class="pswp__bg"></div><div class="pswp__scroll-wrap"><div class="pswp__container"><div class="pswp__item"></div><div class="pswp__item"></div><div class="pswp__item"></div></div><div class="pswp__ui pswp__ui--hidden"><div class="pswp__top-bar"><div class="pswp__counter"></div><button class="pswp__button pswp__button--close" title="' . esc_html__( 'Close (Esc)', 'woocommerce' ) . '"></button> <button class="pswp__button pswp__button--share" title="' . esc_html__( 'Share', 'woocommerce' ) . '"></button> <button class="pswp__button pswp__button--fs" title="' . esc_html__( 'Toggle fullscreen', 'woocommerce' ) . '"></button> <button class="pswp__button pswp__button--zoom" title="' . esc_html__( 'Zoom in/out', 'woocommerce' ) . '"></button><div class="pswp__preloader"><div class="pswp__preloader__icn"><div class="pswp__preloader__cut"><div class="pswp__preloader__donut"></div></div></div></div></div><div class="pswp__share-modal pswp__share-modal--hidden pswp__single-tap"><div class="pswp__share-tooltip"></div></div><button class="pswp__button pswp__button--arrow--left" title="' . esc_html__( 'Previous (arrow left)', 'woocommerce' ) . '"></button> <button class="pswp__button pswp__button--arrow--right" title="' . esc_html__( 'Next (arrow right)', 'woocommerce' ) . '>"></button><div class="pswp__caption"><div class="pswp__caption__center"></div></div></div></div></div>',
				'load_more_button_page_url'              => apply_filters( 'cheshalo_load_more_button_page_url', true ) ? 'yes' : 'no',
				'load_more_button_page_url_opt'          => cheshalo_get_opt( 'load_more_button_page_url', true ) ? 'yes' : 'no',
				'menu_item_hover_to_click_on_responsive' => apply_filters( 'cheshalo_menu_item_hover_to_click_on_responsive', false ) ? 'yes' : 'no',
				'clear_menu_offsets_on_resize'           => apply_filters( 'cheshalo_clear_menu_offsets_on_resize', true ) ? 'yes' : 'no',
				'three_sixty_framerate'                  => apply_filters( 'cheshalo_three_sixty_framerate', 60 ),
				'three_sixty_prev_next_frames'           => apply_filters( 'cheshalo_three_sixty_prev_next_frames', 5 ),
				'ajax_search_delay'                      => apply_filters( 'cheshalo_ajax_search_delay', 300 ),
				'animated_counter_speed'                 => apply_filters( 'cheshalo_animated_counter_speed', 3000 ),
				'site_width'                             => $site_width,
				'cookie_secure_param'                    => cheshalo_cookie_secure_param(),
				'cookie_path'                            => COOKIEPATH,
				'slider_distortion_effect'               => 'sliderWithNoise',
				'current_page_builder'                   => cheshalo_get_current_page_builder(),
				'collapse_footer_widgets'                => cheshalo_get_opt( 'collapse_footer_widgets' ) ? 'yes' : 'no',
				'carousel_breakpoints'                   => cheshalo_get_carousel_breakpoints(),
				'ajax_fullscreen_content'                => cheshalo_get_opt( 'ajax_fullscreen_content', true ) ? 'yes' : 'no',
				'grid_gallery_control'                   => cheshalo_get_opt( 'grid_gallery_control', 'hover' ),
				'grid_gallery_enable_arrows'             => cheshalo_get_opt( 'grid_gallery_enable_arrows', 'none' ),
				'ajax_shop'                              => cheshalo_get_opt( 'ajax_shop' ),
				'add_to_cart_text'                       => esc_html__( 'Add to cart', 'cheshalo' ),
				// translators: %s The name of the previous menu.
				'mobile_navigation_drilldown_back_to'    => esc_html__( 'Back to %s', 'cheshalo' ),
				'mobile_navigation_drilldown_back_to_main_menu'  => esc_html__( 'Back to menu', 'cheshalo' ),
				'mobile_navigation_drilldown_back_to_categories' => esc_html__( 'Back to categories', 'cheshalo' ),
				'ajax_links'                             => apply_filters( 'cheshalo_ajax_links', '.wd-nav-product-cat a, .website-wrapper .widget_product_categories a, .widget_layered_nav_filters a, .woocommerce-widget-layered-nav a, .filters-area:not(.custom-content) a, body.post-type-archive-product:not(.woocommerce-account) .woocommerce-pagination a, body.tax-product_cat:not(.woocommerce-account) .woocommerce-pagination a, .wd-shop-tools a:not(.breadcrumb-link), .cheshalo-woocommerce-layered-nav a, .cheshalo-price-filter a, .wd-clear-filters a, .cheshalo-woocommerce-sort-by a, .woocommerce-widget-layered-nav-list a, .wd-widget-stock-status a, .widget_nav_mega_menu a, .wd-products-shop-view a, .wd-products-per-page a, .category-grid-item a, .wd-cat a, body[class*="tax-pa_"] .woocommerce-pagination a' ),
			)
		);
	}
}

// CSS.
if ( ! function_exists( 'cheshalo_enqueue_base_styles' ) ) {
	function cheshalo_enqueue_base_styles() {
		$uploads = wp_upload_dir();
		$version = cheshalo_get_theme_info( 'Version' );
		$is_rtl  = is_rtl() ? '-rtl' : '';

		if ( cheshalo_is_elementor_installed() ) {
			Elementor\Plugin::$instance->frontend->enqueue_styles();
		}

		wp_deregister_style( 'font-awesome' );
		wp_dequeue_style( 'font-awesome' );

		wp_dequeue_style( 'vc_pageable_owl-carousel-css' );
		wp_dequeue_style( 'vc_pageable_owl-carousel-css-theme' );

		if ( ! defined( 'YITH_WCWL' ) ) {
			wp_deregister_style( 'woocommerce_prettyPhoto_css' );
			wp_dequeue_style( 'woocommerce_prettyPhoto_css' );
		}

		if ( defined( 'WC_STRIPE_VERSION' ) ) {
			wp_deregister_style( 'stripe_styles' );
			wp_dequeue_style( 'stripe_styles' );
		}

		wp_deregister_style( 'contact-form-7' );
		wp_dequeue_style( 'contact-form-7' );
		wp_deregister_style( 'contact-form-7-rtl' );
		wp_dequeue_style( 'contact-form-7-rtl' );

		$wpbfile = get_option( 'cheshalo-generated-wpbcss-file' );
		if ( isset( $wpbfile['name'] ) && 'wpb' === cheshalo_get_opt( 'builder', 'wpb' ) ) {
			$wpbfile_path = set_url_scheme( $uploads['basedir'] . $wpbfile['name'] );
			$wpbfile_url  = set_url_scheme( $uploads['baseurl'] . $wpbfile['name'] );

			$wpbfile_data    = file_exists( $wpbfile_path ) ? get_file_data( $wpbfile_path, array( 'Version' => 'Version' ) ) : array();
			$wpbfile_version = isset( $wpbfile_data['Version'] ) ? $wpbfile_data['Version'] : '';
			if ( $wpbfile_version && version_compare( CHESHALO_WPB_CSS_VERSION, $wpbfile_version, '==' ) ) {
				$inline_styles = wp_styles()->get_data( 'js_composer_front', 'after' );

				wp_deregister_style( 'js_composer_front' );
				wp_dequeue_style( 'js_composer_front' );
				wp_register_style( 'js_composer_front', $wpbfile_url, array(), $version );
				if ( ! empty( $inline_styles ) ) {
					$inline_styles = implode( "\n", $inline_styles );
					wp_add_inline_style( 'js_composer_front', $inline_styles );
				}
			}
		}

		wp_enqueue_style( 'js_composer_front', false, array(), $version );

		if ( 'always' === cheshalo_get_opt( 'font_awesome_css' ) ) {
			if ( 'wpb' === cheshalo_get_current_page_builder() ) {
				wp_enqueue_style( 'vc_font_awesome_5' );
				wp_enqueue_style( 'vc_font_awesome_5_shims' );
			} else {
				wp_enqueue_style( 'elementor-icons-fa-solid' );
				wp_enqueue_style( 'elementor-icons-fa-brands' );
				wp_enqueue_style( 'elementor-icons-fa-regular' );
			}
		}

		wp_enqueue_style( 'bootstrap', CHESHALO_STYLES . '/bootstrap-light.min.css', array(), $version );

		if ( cheshalo_is_combined_needed( 'combined_css' ) ) {
			if ( 'elementor' === cheshalo_get_current_page_builder() ) {
				$style_url = CHESHALO_STYLES . '/style' . $is_rtl . '-elementor.min.css';
			} else {
				$style_url = CHESHALO_THEME_DIR . '/style.min.css';

				if ( $is_rtl ) {
					$style_url = CHESHALO_STYLES . '/style' . $is_rtl . '.min.css';
				}
			}

			wp_enqueue_style( 'cheshalo-style', $style_url, array( 'bootstrap' ), $version );
		} else {
			wp_enqueue_style( 'cheshalo-style', CHESHALO_THEME_DIR . '/css/parts/base' . $is_rtl . '.min.css', array( 'bootstrap' ), $version );
		}

		// Frontend admin bar.
		if ( is_admin_bar_showing() ) {
			wp_enqueue_style( 'cheshalo-frontend-admin-bar', CHESHALO_ASSETS . '/css/parts/base-adminbar.min.css', array(), $version );
		}

		// load typekit fonts.
		$typekit_id = cheshalo_get_opt( 'typekit_id' );

		if ( $typekit_id ) {
			$project_ids = explode( ',', $typekit_id );

			foreach ( $project_ids as $id ) {
				wp_enqueue_style( 'cheshalo-typekit-' . $id, 'https://use.typekit.net/' . esc_attr( $id ) . '.css', array(), $version );
			}
		}

		if ( cheshalo_is_elementor_installed() && function_exists( 'cheshalo_elementor_is_edit_mode' ) && ( cheshalo_elementor_is_edit_mode() || cheshalo_elementor_is_preview_page() || cheshalo_elementor_is_preview_mode() ) ) {
			wp_enqueue_style( 'cheshalo-elementor-editor', CHESHALO_THEME_DIR . '/inc/integrations/elementor/assets/css/editor.css', array(), $version );
		}

		remove_action( 'wp_head', 'print_emoji_detection_script', 7 );
		remove_action( 'wp_print_styles', 'print_emoji_styles' );
	}

	add_action( 'wp_enqueue_scripts', 'cheshalo_enqueue_base_styles', 10000 );
}

if ( ! function_exists( 'cheshalo_force_enqueue_styles' ) ) {
	/**
	 * Force enqueue styles.
	 */
	function cheshalo_force_enqueue_styles() {
		$styles_always = cheshalo_get_opt( 'styles_always_use' );
		if ( is_array( $styles_always ) ) {
			foreach ( $styles_always as $style ) {
				cheshalo_force_enqueue_style( $style );
			}
		}

		$predefined_site_width = cheshalo_get_opt( 'site_width' );

		if ( 'boxed' === $predefined_site_width || 'boxed-2' === $predefined_site_width ) {
			cheshalo_force_enqueue_style( 'layout-wrapper-boxed' );
		}

		$header_settings = whb_get_settings();

		if ( ( isset( $header_settings['overlap'] ) && $header_settings['overlap'] ) && ( isset( $header_settings['boxed'] ) && $header_settings['boxed'] ) ) {
			cheshalo_force_enqueue_style( 'header-boxed' );
		}

		if ( is_active_widget( 0, 0, 'calendar' ) ) {
			cheshalo_force_enqueue_style( 'widget-calendar' );
		}

		if ( is_active_widget( 0, 0, 'rss' ) ) {
			cheshalo_force_enqueue_style( 'widget-rss' );
		}

		if ( is_active_widget( 0, 0, 'woocommerce_product_tag_cloud' ) || is_active_widget( 0, 0, 'tag_cloud' ) ) {
			cheshalo_force_enqueue_style( 'widget-tag-cloud' );
		}

		if ( is_active_widget( 0, 0, 'recent-comments' ) || is_active_widget( 0, 0, 'recent-posts' ) ) {
			cheshalo_force_enqueue_style( 'widget-recent-post-comments' );
		}

		if ( is_active_widget( 0, 0, 'cheshalo-recent-posts' ) ) {
			cheshalo_force_enqueue_style( 'widget-wd-recent-posts' );
		}

		if ( is_active_widget( 0, 0, 'nav_mega_menu' ) ) {
			cheshalo_force_enqueue_style( 'widget-nav-mega-menu' );
		}

		if ( is_active_widget( 0, 0, 'categories' ) || is_active_widget( 0, 0, 'pages' ) || is_active_widget( 0, 0, 'archives' ) || is_active_widget( 0, 0, 'nav_menu' ) ) {
			cheshalo_force_enqueue_style( 'widget-nav' );
		}

		if ( is_active_widget( 0, 0, 'cheshalo-woocommerce-layered-nav' ) ) {
			cheshalo_force_enqueue_style( 'widget-wd-layered-nav' );
			cheshalo_force_enqueue_style( 'woo-mod-swatches-base' );
			cheshalo_force_enqueue_style( 'woo-mod-swatches-filter' );
		}

		if ( is_active_widget( 0, 0, 'woocommerce_product_categories' ) ) {
			cheshalo_force_enqueue_style( 'widget-product-cat' );
		}

		if ( is_active_widget( 0, 0, 'woocommerce_layered_nav' ) || is_active_widget( 0, 0, 'wd-widget-stock-status' ) ) {
			cheshalo_force_enqueue_style( 'widget-layered-nav-stock-status' );
		}

		if ( is_active_widget( 0, 0, 'woocommerce_layered_nav_filters' ) ) {
			cheshalo_force_enqueue_style( 'widget-active-filters' );
		}

		if ( is_active_widget( 0, 0, 'cheshalo-price-filter' ) ) {
			cheshalo_force_enqueue_style( 'widget-price-filter' );
		}

		if ( is_active_widget( 0, 0, 'woocommerce_products' ) || is_active_widget( 0, 0, 'woocommerce_top_rated_products' ) ) {
			cheshalo_force_enqueue_style( 'widget-product-list' );
		}

		if ( is_active_widget( 0, 0, 'woocommerce_widget_cart' ) ) {
			cheshalo_force_enqueue_style( 'widget-shopping-cart' );
		}

		if ( is_active_widget( 0, 0, 'woocommerce_price_filter' ) ) {
			cheshalo_force_enqueue_style( 'widget-slider-price-filter' );
		}

		if ( is_active_widget( 0, 0, 'cheshalo-user-panel' ) ) {
			cheshalo_force_enqueue_style( 'widget-user-panel' );
		}

		if ( is_active_widget( 0, 0, 'woocommerce_rating_filter' ) || is_active_widget( 0, 0, 'woocommerce_recent_reviews' ) || is_active_widget( 0, 0, 'cheshalo-woocommerce-sort-by' ) ) {
			cheshalo_force_enqueue_style( 'widget-woo-other' );
		}

		if ( is_singular( 'post' ) ) {
			cheshalo_force_enqueue_style( 'blog-single-base' );
		}

		if ( cheshalo_get_opt( 'sticky_footer' ) ) {
			cheshalo_force_enqueue_style( 'footer-sticky' );
		}

		if ( cheshalo_get_opt( 'lazy_loading' ) ) {
			cheshalo_force_enqueue_style( 'lazy-loading' );
		}

		if ( is_singular( 'post' ) || cheshalo_is_blog_archive() ) {
			cheshalo_force_enqueue_style( 'blog-base' );
		}

		if ( is_singular( 'portfolio' ) || cheshalo_is_portfolio_archive() ) {
			cheshalo_force_enqueue_style( 'portfolio-base' );
		}

		if ( is_404() ) {
			cheshalo_force_enqueue_style( 'page-404' );
		}

		if ( is_search() ) {
			cheshalo_force_enqueue_style( 'page-search-results' );
		}

		if ( ! cheshalo_get_opt( 'disable_gutenberg_css' ) ) {
			cheshalo_force_enqueue_style( 'wp-gutenberg' );
		}

		if ( class_exists( 'ANR' ) ) {
			cheshalo_force_enqueue_style( 'advanced-nocaptcha', true );
		}

		if ( defined( 'WPCF7_VERSION' ) && cheshalo_get_opt( 'cf7_css_js', '1' ) ) {
			cheshalo_force_enqueue_style( 'wpcf7', true );
		}

		if ( function_exists( '_mc4wp_load_plugin' ) && ! get_option( 'wd_import_theme_version' ) ) {
			cheshalo_force_enqueue_style( 'mc4wp', true );
		}

		if ( class_exists( 'bbPress' ) ) {
			cheshalo_force_enqueue_style( 'bbpress', true );
		}

		if ( class_exists( 'WOOCS_STARTER' ) ) {
			cheshalo_force_enqueue_style( 'woo-curr-switch', true );
		}

		if ( class_exists( 'WeDevs_Dokan' ) ) {
			cheshalo_force_enqueue_style( 'woo-dokan-vend', true );
		}

		if ( class_exists( 'WooCommerce_Germanized' ) ) {
			cheshalo_force_enqueue_style( 'woo-germanized', true );
		}

		if ( defined( 'WC_GATEWAY_PPEC_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'woo-paypal-express', true );
		}

		if ( defined( 'RS_REVISION' ) ) {
			cheshalo_force_enqueue_style( 'revolution-slider', true );
		}

		if ( defined( 'WC_STRIPE_VERSION' ) && cheshalo_woocommerce_installed() && ( is_product() || is_cart() || is_checkout() || is_account_page() ) ) {
			cheshalo_force_enqueue_style( 'woo-stripe', true );
		}

		if ( defined( 'WCPAY_PLUGIN_FILE' ) ) {
			cheshalo_force_enqueue_style( 'woo-payments', true );
		}

		if ( defined( 'KCO_WC_VERSION' ) || defined( 'WC_KLARNA_PAYMENTS_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'woo-klarna', true );
		}

		if ( defined( 'PAYPAL_API_URL' ) ) {
			cheshalo_force_enqueue_style( 'woo-paypal-payments', true );
		}

		if ( class_exists( 'WCFM_Dependencies' ) ) {
			cheshalo_force_enqueue_style( 'woo-wcfm-fm', true );
			cheshalo_force_enqueue_style( 'colorbox-popup', true );
			cheshalo_force_enqueue_style( 'select2' );
		}

		if ( class_exists( 'WC_Dependencies_Product_Vendor' ) ) {
			cheshalo_force_enqueue_style( 'woo-multivendorx', true );
		}

		if ( class_exists( 'WC_Vendors' ) ) {
			cheshalo_force_enqueue_style( 'woo-wc-vendors', true );
		}

		if ( defined( 'ICL_SITEPRESS_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'wpml', true );
		}

		if ( defined( 'YITH_WOOCOMPARE_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'woo-yith-compare', true );
			cheshalo_force_enqueue_style( 'colorbox-popup' );
		}

		if ( defined( 'YITH_WPV_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'woo-yith-vendor', true );
		}

		if ( defined( 'YITH_YWRAQ_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'woo-yith-req-quote', true );

			cheshalo_force_enqueue_style( 'woo-mod-grid' );
			cheshalo_force_enqueue_style( 'woo-mod-quantity' );
			cheshalo_force_enqueue_style( 'woo-mod-shop-table' );
			cheshalo_force_enqueue_style( 'select2' );
		}

		if ( defined( 'YITH_WCWL' ) ) {
			cheshalo_force_enqueue_style( 'woo-yith-wishlist', true );
			cheshalo_force_enqueue_style( 'page-my-account' );
		}

		if ( cheshalo_is_elementor_installed() ) {
			cheshalo_force_enqueue_style( 'elementor-base' );
		}

		if ( defined( 'ELEMENTOR_PRO_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'elementor-pro-base', true );
		}

		if ( defined( 'WPB_VC_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'wpbakery-base' );
			cheshalo_force_enqueue_style( 'wpbakery-base-deprecated', true );
		}

		if ( defined( 'THWEPOF_VERSION' ) || defined( 'THWEPO_VERSION' ) ) {
			cheshalo_force_enqueue_style( 'woo-extra-prod-opt' );
		}

		if ( cheshalo_get_opt( 'sticky_notifications' ) ) {
			cheshalo_force_enqueue_style( 'notices-fixed' );
		}

		if ( cheshalo_woocommerce_installed() ) {
			cheshalo_force_enqueue_style( 'woocommerce-base' );
			cheshalo_force_enqueue_style( 'mod-star-rating' );
			cheshalo_force_enqueue_style( 'woo-el-track-order' );
			cheshalo_force_enqueue_style( 'woocommerce-block-notices' );

			if ( ! cheshalo_get_opt( 'disable_gutenberg_css' ) ) {
				cheshalo_force_enqueue_style( 'woo-gutenberg' );
			}

			if ( is_lost_password_page() ) {
				cheshalo_force_enqueue_style( 'woo-page-lost-password' );
			}

			if ( is_cart() || is_checkout() || is_account_page() ) {
				cheshalo_force_enqueue_style( 'select2' );
				cheshalo_force_enqueue_style( 'woo-mod-shop-table' );
			}

			if ( is_checkout() || is_account_page() ) {
				cheshalo_force_enqueue_style( 'woo-mod-grid' );
			}

			if ( is_cart() ) {
				cheshalo_force_enqueue_style( 'page-cart' );

				if ( Main::get_instance()->has_custom_layout( 'cart' ) ) {
					cheshalo_force_enqueue_style( 'woo-page-cart-builder' );
				} else {
					cheshalo_force_enqueue_style( 'woo-page-cart-predefined' );
				}
			}

			if ( is_cart() || is_product() || ( is_active_widget( 0, 0, 'woocommerce_widget_cart' ) && cheshalo_get_opt( 'mini_cart_quantity' ) ) ) {
				cheshalo_force_enqueue_style( 'woo-mod-quantity' );
			}

			if ( is_checkout() ) {
				cheshalo_force_enqueue_style( 'page-checkout' );
				cheshalo_force_enqueue_style( 'page-checkout-payment-methods' );

				if ( ! Main::get_instance()->has_custom_layout( 'checkout_content' ) && ! Main::get_instance()->has_custom_layout( 'checkout_form' ) ) {
					cheshalo_force_enqueue_style( 'woo-page-checkout-predefined' );
				} else {
					cheshalo_force_enqueue_style( 'woo-page-checkout-builder' );
				}

				if ( Checkout_Order_Table::get_instance()->is_enable_cheshalo_product_table_template() ) {
					cheshalo_force_enqueue_style( 'woo-opt-manage-checkout-prod' );
				}
			}

			if ( defined( 'WC_STRIPE_VERSION' ) && is_account_page() ) {
				cheshalo_force_enqueue_style( 'page-checkout-payment-methods' );
			}

			if ( cheshalo_get_opt( 'shipping_progress_bar_enabled' ) ) {
				if ( cheshalo_get_opt( 'shipping_progress_bar_location_mini_cart' )
					|| is_checkout() && cheshalo_get_opt( 'shipping_progress_bar_location_checkout' ) && ! Main::get_instance()->has_custom_layout( 'checkout_content' )
					|| is_cart() && cheshalo_get_opt( 'shipping_progress_bar_location_card_page' ) && ! Main::get_instance()->has_custom_layout( 'cart' )
					|| is_product() && cheshalo_get_opt( 'shipping_progress_bar_location_single_product' ) && ! Main::get_instance()->has_custom_layout( 'single_product' ) ) {
					cheshalo_force_enqueue_style( 'woo-opt-free-progress-bar' );
					cheshalo_force_enqueue_style( 'woo-mod-progress-bar' );
				}
			}

			if ( is_order_received_page() ) {
				cheshalo_force_enqueue_style( 'woo-page-order-complete' );
			}

			if ( is_order_received_page() || is_account_page() ) {
				cheshalo_force_enqueue_style( 'woo-mod-order-details' );
			}

			if ( is_wc_endpoint_url( 'order-pay' ) ) {
				cheshalo_force_enqueue_style( 'woo-page-checkout-predefined' );
			}

			if ( is_account_page() ) {
				cheshalo_force_enqueue_style( 'page-my-account' );
			}

			if ( is_product() ) {
				cheshalo_force_enqueue_style( 'woo-single-prod-el-base' );
				cheshalo_force_enqueue_style( 'woo-mod-stock-status' );
			}

			if ( is_product_taxonomy() || is_shop() || is_product_category() || is_product_tag() || cheshalo_is_product_attribute_archive() ) {
				cheshalo_force_enqueue_style( 'widget-active-filters' );

				if ( 'disable' !== cheshalo_get_opt( 'shop_widgets_collapse', 'disable' ) ) {
					cheshalo_force_enqueue_style( 'widget-collapse' );
				}

				if ( Main::get_instance()->has_custom_layout( 'shop_archive' ) ) {
					cheshalo_force_enqueue_style( 'woo-shop-builder' );
				} else {
					cheshalo_force_enqueue_style( 'woo-shop-predefined' );
				}

				if ( cheshalo_get_opt( 'shop_categories' ) && ! Main::get_instance()->has_custom_layout( 'shop_archive' ) ) {
					cheshalo_force_enqueue_style( 'shop-title-categories' );
					cheshalo_force_enqueue_style( 'woo-categories-loop-nav-mobile-accordion' );
				}
			}

			if ( ! Main::get_instance()->has_custom_layout( 'shop_archive' ) && ( is_product_taxonomy() || is_shop() || is_product_category() || is_product_tag() || cheshalo_is_product_attribute_archive() || ( function_exists( 'wcfm_is_store_page' ) && wcfm_is_store_page() ) ) ) {
				cheshalo_force_enqueue_style( 'woo-shop-el-products-per-page' );
				cheshalo_force_enqueue_style( 'woo-shop-page-title' );
				cheshalo_force_enqueue_style( 'woo-mod-shop-loop-head' );

				if ( ! cheshalo_get_opt( 'shop_filters' ) ) {
					cheshalo_force_enqueue_style( 'woo-shop-el-order-by' );
				}

				if ( cheshalo_get_opt( 'per_row_columns_selector' ) && cheshalo_get_opt( 'products_columns_variations' ) ) {
					cheshalo_force_enqueue_style( 'woo-shop-el-products-view' );
				}

				if ( ! cheshalo_get_opt( 'shop_title' ) ) {
					cheshalo_force_enqueue_style( 'woo-shop-opt-without-title' );
				}
			}

			if ( cheshalo_get_opt( 'bought_together_enabled', 1 ) && ( is_cart() || is_checkout() ) ) {
				cheshalo_force_enqueue_style( 'woo-opt-fbt-cart' );
			}

			$compare_page  = function_exists( 'wpml_object_id_filter' ) ? wpml_object_id_filter( cheshalo_get_opt( 'compare_page' ), 'page', true ) : cheshalo_get_opt( 'compare_page' );
			$wishlist_page = function_exists( 'wpml_object_id_filter' ) ? wpml_object_id_filter( cheshalo_get_opt( 'wishlist_page' ), 'page', true ) : cheshalo_get_opt( 'wishlist_page' );

			if ( $compare_page && (int) cheshalo_get_the_ID() === (int) $compare_page ) {
				cheshalo_force_enqueue_style( 'page-compare' );
				cheshalo_force_enqueue_style( 'woo-mod-stock-status' );
			}

			if ( $wishlist_page && (int) cheshalo_get_the_ID() === (int) $wishlist_page ) {
				cheshalo_force_enqueue_style( 'page-wishlist' );
				cheshalo_force_enqueue_style( 'page-my-account' );
			}

			if ( cheshalo_get_opt( 'hide_larger_price' ) ) {
				cheshalo_force_enqueue_style( 'woo-opt-hide-larger-price' );
			}

			if ( cheshalo_get_opt( 'attr_after_short_desc' ) || 'additional_info' === cheshalo_get_opt( 'base_hover_content' ) || is_product() ) {
				cheshalo_force_enqueue_style( 'woo-mod-shop-attributes' );
			}
		}

		if ( cheshalo_get_opt( 'disable_owl_mobile_devices' ) ) {
			cheshalo_force_enqueue_style( 'opt-carousel-disable' );
		}

		if ( 'underlined' === cheshalo_get_opt( 'form_fields_style' ) ) {
			cheshalo_force_enqueue_style( 'opt-form-underline' );
		}

		if ( class_exists( 'WeDevs_Dokan' ) && ( dokan_is_store_page() || dokan_is_store_listing() || dokan_is_seller_dashboard() ) ) {
			cheshalo_force_enqueue_style( 'select2' );
		}
	}

	add_action( 'wp_enqueue_scripts', 'cheshalo_force_enqueue_styles', 10001 );
}

if ( ! function_exists( 'cheshalo_enqueue_product_loop_styles' ) ) {
	/**
	 * Enqueue product loop style files.
	 *
	 * @param string $design Design.
	 */
	function cheshalo_enqueue_product_loop_styles( $design ) {
		cheshalo_enqueue_inline_style( 'product-loop' );

		if ( 'button' === $design || 'info-alt' === $design ) {
			cheshalo_enqueue_inline_style( 'product-loop-button-info-alt' );
		} else {
			cheshalo_enqueue_inline_style( 'product-loop-' . $design );
		}

		if ( in_array( $design, array( 'standard', 'button', 'base', 'info-alt', 'quick', 'list', 'fw-button', 'buttons-on-hover' ), true ) && ! cheshalo_get_opt( 'catalog_mode' ) ) {
			cheshalo_enqueue_inline_style( 'woo-mod-add-btn-replace' );
		}

		if ( cheshalo_loop_prop( 'product_quantity' ) ) {
			cheshalo_enqueue_inline_style( 'woo-mod-quantity' );
			cheshalo_enqueue_inline_style( 'woo-mod-quantity-overlap' );
		}

		if ( cheshalo_get_opt( 'grid_swatches_attribute' ) ) {
			cheshalo_enqueue_inline_style( 'woo-mod-swatches-base' );
		}

		if ( 'base' === $design || 'fw-button' === $design ) {
			cheshalo_enqueue_inline_style( 'mod-more-description' );
		}
	}
}

if ( ! function_exists( 'cheshalo_enqueue_portfolio_loop_styles' ) ) {
	/**
	 * Enqueue product loop style files.
	 *
	 * @param string $design Design.
	 */
	function cheshalo_enqueue_portfolio_loop_styles( $design ) {
		if ( 'hover' === $design ) {
			cheshalo_enqueue_inline_style( 'project-text-hover' );
		}

		if ( 'hover-inverse' === $design ) {
			cheshalo_enqueue_inline_style( 'project-alt' );
		}

		if ( 'text-shown' === $design ) {
			cheshalo_enqueue_inline_style( 'project-under' );
		}

		if ( 'parallax' === $design ) {
			cheshalo_enqueue_inline_style( 'project-parallax' );
		}
	}
}

if ( ! function_exists( 'cheshalo_enqueue_inline_style' ) ) {
	/**
	 * Enqueue inline style by key.
	 *
	 * @param string $key File slug.
	 */
	function cheshalo_enqueue_inline_style( $key, $ignore_combined = false ) {
		if ( function_exists( 'wc' ) && ( wc()->is_rest_api_request() || cheshalo_is_woocommerce_legacy_rest_api() ) ) {
			return;
		}

		Parts_Css_Files::get_instance()->enqueue_inline_style( $key, $ignore_combined );
	}
}

if ( ! function_exists( 'cheshalo_force_enqueue_style' ) ) {
	/**
	 * Enqueue style by key.
	 *
	 * @param string $key File slug.
	 */
	function cheshalo_force_enqueue_style( $key, $ignore_combined = false ) {
		Parts_Css_Files::get_instance()->enqueue_style( $key, $ignore_combined );
	}
}

if ( ! function_exists( 'cheshalo_enqueue_inline_style_anchor' ) ) {
	function cheshalo_enqueue_inline_style_anchor() {
		wp_enqueue_style( 'cheshalo-inline-css' );
	}

	add_action( 'wp_footer', 'cheshalo_enqueue_inline_style_anchor', 10 );
}
